[Lldb-commits] [lldb] 8f329ce - [lldb] Split TestCxxChar8_t

Jonas Devlieghere via lldb-commits lldb-commits at lists.llvm.org
Wed Dec 1 16:58:47 PST 2021


Author: Jonas Devlieghere
Date: 2021-12-01T16:58:43-08:00
New Revision: 8f329cee423735c2767d3ba490e39db49f649c21

URL: https://github.com/llvm/llvm-project/commit/8f329cee423735c2767d3ba490e39db49f649c21
DIFF: https://github.com/llvm/llvm-project/commit/8f329cee423735c2767d3ba490e39db49f649c21.diff

LOG: [lldb] Split TestCxxChar8_t

Split TestCxxChar8_t into two parts: one that check reading variables
without a process and another part with. This allows us to skip the
former on Apple Silicon, where lack of support for chained fix-ups
causes the test to fail.

Differential revision: https://reviews.llvm.org/D114819

Added: 
    

Modified: 
    lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py

Removed: 
    


################################################################################
diff  --git a/lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py b/lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
index b069afc1bbf7d..71dfdbc6e66bd 100644
--- a/lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
+++ b/lldb/test/API/lang/cpp/char8_t/TestCxxChar8_t.py
@@ -15,13 +15,12 @@ class CxxChar8_tTestCase(TestBase):
     mydir = TestBase.compute_mydir(__file__)
 
     @skipIf(compiler="clang", compiler_version=['<', '7.0'])
-    def test(self):
-        """Test that C++ supports char8_t correctly."""
+    @expectedFailureDarwin(archs=["arm64", "arm64e"]) # <rdar://problem/37773624>
+    def test_without_process(self):
+        """Test that C++ supports char8_t without a running process."""
         self.build()
-
         lldbutil.run_to_breakpoint_make_target(self)
 
-        # Make sure the variables can be printed without a running process.
         self.expect("target variable a", substrs=["char8_t", "0x61 u8'a'"])
         self.expect("target variable ab",
                 substrs=["const char8_t *", 'u8"你好"'])
@@ -29,11 +28,16 @@ def test(self):
 
         self.expect_expr("a", result_type="char8_t", result_summary="0x61 u8'a'")
         self.expect_expr("ab", result_type="const char8_t *", result_summary='u8"你好"')
+
         # FIXME: This should work too.
         self.expect("expr abc", substrs=['u8"你好"'], matching=False)
 
-        lldbutil.run_break_set_by_source_regexp(self, "// break here", "-f main.cpp")
-        self.runCmd("run")
+
+    @skipIf(compiler="clang", compiler_version=['<', '7.0'])
+    def test_with_process(self):
+        """Test that C++ supports char8_t with a running process."""
+        self.build()
+        lldbutil.run_to_source_breakpoint(self, '// break here', lldb.SBFileSpec("main.cpp"))
 
         # As well as with it
         self.expect_expr("a", result_type="char8_t", result_summary="0x61 u8'a'")


        


More information about the lldb-commits mailing list